@@ -41,9 +41,6 @@ UNICODE_CATEGORIES: Categories = {
     "Sc": None,
     "Sk": None,
     "So": WS,
-    "Zs": WS,
-    "Zl": WS,
-    "Zp": WS,
 }
 
 SLUG_CATEGORIES: Categories = {
@@ -71,10 +68,7 @@ SLUG_CATEGORIES: Categories = {
     "Sc": None,
     "Sk": None,
     "So": WS,
-    "Zs": WS,
-    "Zl": WS,
-    "Zp": WS,
 }
 
 
-CONTROL_CODES: Categories = {"Cc": WS, "Cf": WS, "Cs": WS, "Co": WS, "Cn": WS}
+CONTROL_CODES: Categories = {"Cc": WS, "Cf": WS, "Cs": WS, "Co": WS, "Cn": WS, "Zl": WS}
